/*******************************************************************************
 * SoftTimerExt example
 *
 * In the public domain.
 *
 * v1.0, 05 Sep 2016  Volker Kuhlmann
 *   Created.
 *******************************************************************************
 */

#include <SoftTimer.h>

SoftTimerExt timer1;
SoftTimerExt timer_progress;

void setup() {
  Serial.begin(115200);
  Serial.println("\r\nSoftTimerExt example\r\n");

  // Start timer_progress, 10s delay.
  timer_progress.start(10000);
}

void loop() {
  if (millis() <= 2000) { // some condition
    // Start timer (repeatedly) during first 2s of runtime.
    timer1.start(1300);
  }
  if (timer1.is_expired()) {
    Serial.print("  Timer 1 expired, at ms "); Serial.println(millis());

    // Restart timer with the previously used delay (1.3s).
    // NOTE: .restart() only works after one of .start(), .startW(), .startN()
    // have been used at least once.
    timer1.restart();
  }

  // For progressive output:
  if (timer_progress.is_new_s()) {
    Serial.print("Timer 2 (s) elapsed: ");
    Serial.print(timer_progress.elapsed_s());
    Serial.print("\tremaining ");
    Serial.print(timer_progress.remaining_s());
    Serial.print("\tAt ms "); Serial.println(millis());
  }
  if (timer_progress.is_expired()) {
    Serial.print("Timer 2 finished!\t\t\tAt ms "); Serial.println(millis());
    timer_progress.restart();
  }

  while (millis() > 31500); // Stop after 31.5s.

  // NOTE:
  // .start() takes a 2-byte argument (up to 65565 milliseconds),
  // which is most common.
  // For delays larger than 65565 ms use .startW().
  // For delays up to 255 ms use .startN(), which gives shorter programs.
}
